# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-10-26 09:32
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='SMS',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('number', models.CharField(max_length=21)),
                ('sign', models.CharField(default=b'InfoNomer', max_length=21)),
                ('message', models.TextField(max_length=1530)),
                ('wappush', models.CharField(max_length=128)),
                ('is_flash', models.BooleanField(default=False)),
            ],
        ),
        migrations.CreateModel(
            name='SMSRecord',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('msg_id', models.CharField(max_length=36)),
                ('number', models.CharField(max_length=21)),
                ('sign', models.CharField(default=b'InfoNomer', max_length=21)),
                ('message', models.TextField(max_length=1530)),
                ('wappush', models.CharField(max_length=128)),
                ('is_flash', models.BooleanField(default=False)),
                ('cost', models.DecimalField(decimal_places=2, max_digits=4)),
                ('balance', models.DecimalField(decimal_places=2, max_digits=10)),
                ('added', models.DateTimeField()),
                ('send_time', models.DateTimeField()),
                ('sended', models.DateTimeField()),
                ('received', models.DateTimeField()),
                ('error_code', models.CharField(max_length=3)),
                ('status', models.CharField(max_length=255)),
            ],
        ),
    ]
